============
Blazar Specs
============

Stein
-----

This section has a list of specs for Stein release.


.. toctree::
   :maxdepth: 1
   :glob:

   stein/*

Rocky
-----

This section has a list of specs for Rocky release.


.. toctree::
   :maxdepth: 1
   :glob:

   rocky/*

Queens
------

This section has a list of specs for Queens release.


.. toctree::
   :maxdepth: 1
   :glob:

   queens/*

Pike
----

This section has a list of specs for Pike release.


.. toctree::
   :maxdepth: 1
   :glob:

   pike/*
